@@ -1,40 +1,47 @@
-#' Coerce a data frame to SpatRaster
+#' Coerce a data frame to `SpatRaster`
 #'
 #' @description
 #'
-#' `as_spatraster()` turns an existing  data frame or tibble, into a SpatRaster.
-#' This is a wrapper of [terra::rast()] S4 method for `data.frame`.
+#' `as_spatraster()` turns an existing  data frame or [`tibble`][tibble::tibble]
+#' into a `SpatRaster`. This is a wrapper of [terra::rast()] S4 method for
+#' signature `data.frame`.
 #'
 #' @return
-#' A SpatRaster.
+#' A `SpatRaster`.
 #'
 #' @export
 #'
-#' @param x A tibble or data frame.
+#' @param x A [`tibble`][tibble::tibble()] or data frame.
 #' @param xycols A vector of integers of length 2 determining the position of
 #'   the columns that hold the x and y coordinates.
+#'
 #' @param digits integer to set the precision for detecting whether points are
 #'   on a regular grid (a low number of digits is a low precision).
 #'
 #' @param crs A crs on several formats (PROJ.4, WKT, EPSG code, ..) or
-#'   and spatial object from sf or terra that includes the target coordinate
-#'   reference system. See [pull_crs()]. See **Details**.
+#'   and spatial object from **[sf][sf::st_crs()]** or
+#'   **[terra][terra::crs()]**.
+#'   that includes the target coordinate reference system. See [pull_crs()] and
+#'   **Details**.
 #'
 #' @param ... additional arguments passed on to [terra::rast()].
 #'
 #' @details
 #'
-#' `r lifecycle::badge('questioning')` If no `crs` is provided and the tibble
-#' has been created with the method [as_tibble.SpatRaster()], the `crs` is
-#' inferred from `attr(x, "crs")`.
+#' If no `crs` is provided and the tibble has been created with the method
+#' [as_tibble.SpatRaster()], the `crs` is inferred from
+#' [`attr(x, "crs")`][attr()].
 #'
 #' @family coerce
 #'
-#' @seealso [pull_crs()]
+#' @seealso
 #'
-#' @section terra equivalent:
+#' [pull_crs()] for retrieving crs, and the corresponding utils [sf::st_crs()]
+#' and [terra::crs()].
 #'
-#' [terra::rast()]
+#' @section \CRANpkg{terra} equivalent:
+#'
+#' [terra::rast()] (see S4 method for signature `data.frame`).
 #'
 #' @examples
 #' library(terra)
@@ -81,6 +88,20 @@ as_spatraster <- function(x, ..., xycols = 1:2, crs = "", digits = 6) {
 
   xycols <- as.integer(xycols)
 
+  # Check if is fortified pivoted and widen it
+  if (isTRUE(attr(x, "pvt_fort"))) {
+    initcrs <- attr(x, "crs")
+    x <- x[, 1:4]
+
+    # lyrs
+    names(x) <- c("x", "y", "name", "value")
+    x <- tidyr::pivot_wider(x)
+
+    attr(x, "crs") <- initcrs
+  }
+
+
+
   # To tibble
   x <- tibble::as_tibble(x)
 
@@ -171,12 +192,13 @@ as_spatraster <- function(x, ..., xycols = 1:2, crs = "", digits = 6) {
 
   names(defortify) <- layer_names
 
-  return(defortify)
+  defortify
 }
 
-#' Rebuild objects created with as_tbl_spatattr to SpatRaster
+#' Rebuild objects created with as_tbl_spatattr to `SpatRaster`
 #' Strict version, used attributes for creating a template
-#' SpatRaster and then transfer the values
+#' `SpatRaster` and then transfer the values
+#'
 #' @noRd
 as_spatrast_attr <- function(x) {
   if (inherits(x, "SpatRaster")) {
@@ -218,5 +240,5 @@ as_spatrast_attr <- function(x) {
   defortify <- do.call("c", temp_list)
   names(defortify) <- names(values)
 
-  return(defortify)
+  defortify
 }
